# [pjz](https://github.com/spinsphotonics/fdtdz) 😴👕👖💤 -- a small toolset for photonics on JAX

**pjz** is [JAX](https://github.com/google/jax) and [fdtd-z](https://github.com/spinsphotonics/fdtdz), a set of tools for runnning photonic simulation and optimization workflows at scale.


